<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2008 Frans van der Veen [netcreators] <extensions@netcreators.com>
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

use TYPO3\CMS\Frontend\Plugin\AbstractPlugin;
use TYPO3\CMS\Core\Utility\GeneralUtility;

$currentDir = dirname(__FILE__) . '/';
require_once($currentDir . '../includes.php');

if($errorMode) {
	class tx_ncfoldabletxt_controller extends AbstractPlugin {
		// Same as class name
		public $prefixId      = 'tx_ncfoldabletxt_controller';

		// NOTE the false path helps the pibase class find the locallang.xml
		// Not used elsewhere
		// Path to this script relative to the extension dir.
		public $scriptRelPath = 'lang/class.tx_ncfoldabletxt_controller.php';

		// The extension key.
		// same as $_EXTKEY and $_EXTKEYSHORT
		public $extKey      = 'nc_foldabletxt';
		public $extKeyShort = 'tx_ncfoldabletxt';
		public $pi_checkCHash = true;
		function getContent($content, $configuration) {
			return 'Error: NCLIB was not loaded';
		}
	}
	return;
}

/**
 * Plugin 'Template' for the 'nc_foldabletxt' extension.
 *
 * @author	Frans van der Veen <extensions@netcreators.com>
 * @package	TYPO3
 * @subpackage	tx_ncfoldabletxt
 */
class tx_ncfoldabletxt_controller extends tx_ncfoldabletxt_base_controller {
	// Same as class name
	public $prefixId      = 'tx_ncfoldabletxt_controller';

	// NOTE the false path helps the AbstractPlugin class find the locallang.xml
	// Not used elsewhere
	// Path to this script relative to the extension dir.
	public $scriptRelPath = 'lang/class.tx_ncfoldabletxt_controller.php';

	// The extension key.
	// same as $_EXTKEY and $_EXTKEYSHORT
	public $extKey      = 'nc_foldabletxt';
	public $extKeyShort = 'tx_ncfoldabletxt';
	public $pi_checkCHash = true;

	/**
	 * @var tx_ncfoldabletxt_content_view
	 */
	protected $view = null;

	/**
	 * (Overriding tx_nclib_base_controller::$configModel merely for easier PHPDoc type annotation)
	 *
	 * @var tx_ncfoldabletxt_config_model
	 */
	public $configModel = null;

	/**
	 * Initializes the class (all the models, input variables, etc...)
	 *
	 * @param array		$configuration	typoscript configuration
	 */
	public function initialize($configuration) {
		// call parent
		parent::initialize($configuration);
		// for configuration values, see the config model for this plugin
		$this->configModel = GeneralUtility::makeInstance($this->extKeyShort . '_config_model');
		$this->configModel->initialize($this, $configuration);

		$this->view = GeneralUtility::makeInstance($this->extKeyShort . '_content_view');
		$this->view->initialize($this);
	}

	/**
	 * The main method of the Plugin
	 *
	 * @param    string $content : The Plugin content
	 * @param $configuration : The Plugin configuration
	 * @return string   The content that is displayed on the website
	 */
	function pluginAction($content, $configuration) {
		try {
			$this->initialize($configuration);
			$this->view->setSubparts(
				array(
					'contentid' => $this->cObj->data['uid'],
					'header' => $this->cObj->data['header'],
					'subheader' => $this->cObj->data['subheader'],
					'bodytext' => $this->pi_RTEcssText($this->cObj->data['bodytext']),
				)
			);
			$content = $this->view->setMainPart('CONTENT_VIEW')->getOutput();
			if($this->configModel->get('wrapInBaseClass')) {
				$content = $this->pi_wrapInBaseClass($content);
			}
		} catch(Exception $exception) {
			$content = $this->getException($exception);
		}
		return $content;
	}

	/**
	 * Renders the exception view with details from the exception, or just shows exception information if an exception
	 * occurs in the exception view rendering.
	 *
	 * @param object 	$exception	exception object
	 * @return string	the content
	 */
	function getException(&$exception) {
		try {
			/** @var tx_ncfoldabletxt_exception_view $exceptionView */
			$exceptionView = GeneralUtility::makeInstance($this->extKeyShort . '_exception_view');
			$exceptionView->initialize($this);
			$content = $exceptionView->getContent($exception);
		} catch(Exception $critical) {
			$content = '<strong>Critical: Exception in exception handler:</strong>';
			$content .= $critical->getMessage();
			$content .= nl2br($critical->getTraceAsString());
			$content .= '<br /><hr /><br />';
			$content .= '<strong>Original exception:</strong>';
			$content .= $exception->getMessage();
			$content .= nl2br($exception->getTraceAsString());
		}
		return $content;
	}
}

?>
